(define-module (glicid packages caddy)
               #:use-module (guix build-system gnu)
               #:use-module (guix download)
               #:use-module (guix git-download)
               #:use-module (guix packages)
               #:use-module ((guix licenses) #:prefix license:)
               #:use-module (guix build-system copy)
               #:use-module (guix build-system go)
               #:use-module (gnu packages gl)
               #:use-module (gnu packages golang)
               #:use-module (gnu packages golang-build)
               #:use-module (gnu packages golang-check)
               #:use-module (gnu packages golang-web)
               #:use-module (gnu packages golang-xyz)

               )


(define-public caddy-dirty
               (package
                 (name "caddy-dirty")
                 (version "2.8.4")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/caddyserver/caddy/releases/download/v" version "/caddy_" version "_linux_amd64.tar.gz"))
                           (sha256 (base32 "1j286xfxcrzvgn4k02nnq7n45wdsyz5c0phw6y7gi30kain31s57"))))
                 (build-system copy-build-system)
                 (arguments
                   `(#:install-plan `(("caddy" "/sbin/"))))
                 (synopsis "Caddy is an extensible server platform that uses TLS by default. Dirty Version.")
                 (description "Caddy is an extensible server platform that uses TLS by default. Dirty Version")
                 (home-page "https://github.com/caddyserver/caddy")
                 (license license:expat)))

(define-public caddy-dirty-with-replace
               (package
                 (name "caddy-dirty-with-replace")
                 (version "2.8.4")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://forgejo.glicid.fr/api/packages/GLiCID/generic/caddy-for-guix/v" version "/caddy-" version "-replaceresponse.tar.gz"))
                           (sha256 (base32 "16rbxld5pg7w1a7j22rfkaihs3867ign4qbml5a6psnn4v8blcxh"))))
                 (build-system copy-build-system)
                 (arguments
                   `(#:install-plan `(("caddy" "/sbin/"))))
                 (synopsis "Caddy is an extensible server platform that uses TLS by default. Dirty Version.")
                 (description "Caddy is an extensible server platform that uses TLS by default. Dirty Version")
                 (home-page "https://github.com/caddyserver/caddy")
                 (license license:expat)))

(define-public caddy-dirty-with-extensions
               (package
                 (name "caddy-dirty-with-extensions")
                 (version "2.8.4")
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://forgejo.glicid.fr/api/packages/GLiCID/generic/caddy-for-guix/v" version "/caddy-" version "-full.tar.gz"))
                           (sha256 (base32 "0y4rsg94ngp85ma02axfdwfj72h1bwac3hf4kykym2dzyydgcvf7"))))
                 (build-system copy-build-system)
                 (arguments
                   `(#:install-plan `(("caddy" "/sbin/"))))
                 (synopsis "Caddy is an extensible server platform that uses TLS by default. Dirty Version.")
                 (description "Caddy is an extensible server platform that uses TLS by default. Dirty Version")
                 (home-page "https://github.com/caddyserver/caddy")
                 (license license:expat)))

(define-public go-github-com-akavel-rsrc
  (package
    (name "go-github-com-akavel-rsrc")
    (version "0.10.2")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://github.com/akavel/rsrc")
             (commit (string-append "v" version))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "1frdxqdnk923p4245lk0wwqrxsdy8aj2qxl3m0zfgnh02vfz3hs2"))))
    (build-system go-build-system)
    (arguments
     (list
      #:import-path "github.com/akavel/rsrc"))
    (home-page "https://github.com/akavel/rsrc")
    (synopsis #f)
    (description #f)
    (license license:expat)))

(define-public go-github-com-josephspurrier-goversioninfo
  (package
    (name "go-github-com-josephspurrier-goversioninfo")
    (version "1.4.1")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://github.com/josephspurrier/goversioninfo")
             (commit (string-append "v" version))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "02nqhkvsxi69ny64j81x1k142fir2ps68fypi3z2hr4wd3x4i1l9"))))
    (build-system go-build-system)
    (arguments
     (list
      #:import-path "github.com/josephspurrier/goversioninfo"))
    (propagated-inputs (list go-github-com-stretchr-testify
                             go-github-com-akavel-rsrc))
    (home-page "https://github.com/josephspurrier/goversioninfo")
    (synopsis "GoVersionInfo")
    (description
     "Package goversioninfo creates a syso file which contains Microsoft Version
Information and an optional icon.")
    (license license:expat)))

(define-public go-github-com-caddyserver-xcaddy
  (package
    (name "go-github-com-caddyserver-xcaddy")
    (version "0.4.2")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://github.com/caddyserver/xcaddy")
             (commit (string-append "v" version))))
       (file-name (git-file-name name version))
       (sha256
        (base32 "1452m1wksxmhy00rdkpnh55y8bxyxxcldapvp0fzpsyv82kfmsz1"))))
    (build-system go-build-system)
    (arguments
     (list
      #:import-path "github.com/caddyserver/xcaddy"))
    (propagated-inputs (list go-github-com-josephspurrier-goversioninfo
                             go-github-com-google-shlex
                             go-github-com-masterminds-semver-v3))
    (home-page "https://github.com/caddyserver/xcaddy")
    (synopsis "- Custom Caddy Builder")
    (description
     "This command line tool and associated Go package makes it easy to make custom
builds of the @@url{https://github.com/caddyserver/caddy,Caddy Web Server}.")
    (license license:asl2.0)))

caddy-dirty-with-extensions
