(define-module (glicid packages vpn)
               #:use-module (guix)
               #:use-module (ice-9 match)
               #:use-module ((guix licenses) #:prefix license:)
               #:use-module (guix utils)
               #:use-module (guix download)
               #:use-module (guix git-download)
               #:use-module (guix packages)
               #:use-module (guix build-system copy)
               #:use-module (guix build-system go)
               #:use-module (nonguix build-system binary)
               #:use-module (gnu packages dns)
               #:use-module (gnu packages gl)
               #:use-module (gnu packages golang)
               #:use-module (gnu packages golang-build)
               #:use-module (gnu packages golang-web)
               #:use-module (gnu packages golang-xyz)
               #:use-module (gnu packages linux)
               #:use-module (gnu packages xorg)
               )

(define %netbird-version "0.30.3")

(define-public netbird-cli
               (package
                 (name "netbird-cli")
                 (version %netbird-version)
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/netbirdio/netbird/releases/download/v" version "/netbird_" version "_linux_amd64.tar.gz"))
                           (sha256 (base32 "0bdszkkl2y1r0jqljkkia3pppw8ymsyd2d83qdkvc0cvc3ycnsh8"))))
                 (build-system copy-build-system)
                 (arguments
                   `(#:install-plan `(("netbird" "/bin/"))))
                 (propagated-inputs (list openresolv iptables nftables ebtables))
                 (synopsis "NetBird combines a configuration-free peer-to-peer private network and a centralized access control system in a single platform, making it easy to create secure private networks for your organization or home.
Connect. NetBird creates a WireGuard-based overlay network that automatically connects your machines over an encrypted tunnel, leaving behind the hassle of opening ports, complex firewall rules, VPN gateways, and so forth.
Secure. NetBird enables secure remote access by applying granular access policies while allowing you to manage them intuitively from a single place. Works universally on any infrastructure.")
                 (description "netbird client cli program. dirty version from github artifacts.")
                 (home-page "https://github.com/netbirdio/netbird")
                 (license license:expat)))

(define-public go-netbird-cli
               (package
                 (name "go-netbird-cli")
                 (version %netbird-version)
                 (source (origin
                           (method git-fetch)
                           (uri (git-reference
                                  (url "https://github.com/netbirdio/netbird")
                                  (commit (string-append "v" version))))
                           (file-name (git-file-name name version))
                           (sha256 (base32 "19xyw6vxwag4w71zm998jjlv19cvrgwrzlpq0jrhbm8yf8jpjvs8"))))
                 (build-system go-build-system)
                 (native-inputs (list go-github-com-cenkalti-backoff-v4
                               go-github-com-ayufan-golang-kardianos-service
                               go-github-com-google-uuid
                               go-github-com-pion-ice-v3
                               go-github-com-pion-logging
                               go-github-com-pion-stun-v2
                               go-github-com-pion-transport-v3
                               go-github-com-sirupsen-logrus
                               go-golang-zx2c4-com-wireguard
                               go-github-com-google-gopacket
                               go-github-com-libp2p-go-netroute
                               go-github-com-mdlayher-socket
                               go-github-com-hashicorp-go-multierror
                               go-github-com-godbus-dbus-v5
                               go-github-com-vishvananda-netlink
                               go-gopkg-in-natefinch-lumberjack.v2
                               go-google-golang-org-protobuf
                               go-github-com-spf13-pflag
                               go-github-com-spf13-cobra
                               go-github-com-skratchdot-open-golang
                               go-golang-org-x-oauth2
                               go-github-com-miekg-dns
                               go-github-com-hashicorp-go-version
                               go-github-com-fsnotify-fsnotify
                               ))
                 (arguments
                   `(#:import-path "github.com/netbirdio/netbird"
                     #:phases
                     (modify-phases %standard-phases
                                    (replace 'build
                                                (lambda _
                                                  (invoke "go" "build" "-C" "src/github.com/netbirdio/netbird/client")
                                                  )))))
                 (synopsis "")
                 (description "")
                 (home-page "")
                 (license #f)
                 ))

(define-public netbird-ui
               (package
                 (name "netbird-ui")
                 (version %netbird-version)
                 (source (origin
                           (method url-fetch)
                           (uri (string-append "https://github.com/netbirdio/netbird/releases/download/v" version "/netbird-ui-linux_" version "_linux_amd64.tar.gz"))
                           (sha256 (base32 "05zgibbjwgmffdxz9b4ikiw06rdpp20ccpxq87286m4vwl4ad907"))))
                 (build-system binary-build-system)
                 (inputs (list libx11 libglvnd))
                 (arguments
                   `(#:install-plan `(("netbird-ui" "/bin/"))
                     #:patchelf-plan `(("netbird-ui" ("libx11" "libglvnd")))
                     #:strip-binaries? #f))
                 (synopsis "NetBird combines a configuration-free peer-to-peer private network and a centralized access control system in a single platform, making it easy to create secure private networks for your organization or home.
Connect. NetBird creates a WireGuard-based overlay network that automatically connects your machines over an encrypted tunnel, leaving behind the hassle of opening ports, complex firewall rules, VPN gateways, and so forth.
Secure. NetBird enables secure remote access by applying granular access policies while allowing you to manage them intuitively from a single place. Works universally on any infrastructure.")
                 (description "netbird client ui program. dirty version from github artifacts.")
                 (home-page "https://github.com/netbirdio/netbird")
                 (license license:expat)))
