(define-module (glicid packages web)
               #:use-module (guix build-system gnu)
               #:use-module (guix download)
               #:use-module (guix packages)
               #:use-module ((guix licenses) #:prefix license:)
               #:use-module (gnu packages adns)
               #:use-module (gnu packages xml)
               #:use-module (gnu packages tls)
               #:use-module (gnu packages linux)
               #:use-module (gnu packages compression)
               #:use-module (gnu packages libevent)
               #:use-module (gnu packages pkg-config)
               #:use-module (gnu packages check)
               #:use-module (gnu packages python)
               #:use-module (gnu packages base)
               #:use-module ((gnu packages web) #:prefix gnu:)
               )

(define-public nghttp2
               (package
                 (name "nghttp2")
                 (version "1.52.0")
                 (source (origin
                           (method url-fetch)
                           (uri (list (string-append "https://github.com/"name "/" name "/releases/download/v" version "/" name "-" version ".tar.xz")))
                           (sha256 (base32 "0zdsz0hrv7zypykhd3kyvllvkzw4hs9lkcwwsga9lik0kr1z1a9y"))))
                 (build-system gnu-build-system)
                 (outputs (list "out" "lib"))
                 (native-inputs
                   (list pkg-config cunit python tzdata-for-tests))
                 (inputs (list c-ares gnu:jansson libev libxml2 openssl libbpf zlib ))
                 (arguments
                   `(#:configure-flags
                     (list (string-append "--libdir=" (assoc-ref %outputs "lib") "/lib")
                           "--enable-app"
                           "--enable-hpack-tools"
                           "--disable-examples"
                           "--disable-static"
                           ,@(if (%current-target-system)
                               '("--disable-python-bindings")
                               '()))
                     #:phases
                     (modify-phases %standard-phases
                                    (add-after 'unpack 'break-circular-reference
                                               (lambda* (#:key outputs #:allow-other-keys)
                                                        (substitute* "lib/libnghttp2.pc.in"
                                                                     (("@prefix@")
                                                                      (assoc-ref outputs "lib")))
                                                        #t))
                                    (add-before 'check 'set-timezone-directory
                                                (lambda* (#:key inputs native-inputs #:allow-other-keys)
                                                         (setenv "TZDIR" (string-append
                                                                           (assoc-ref (or native-inputs inputs) "tzdata")
                                                                           "/share/zoneinfo"))
                                                         #t)))))
                 (home-page "https://nghttp2.org/")
                 (synopsis "HTTP/2 protocol client, proxy, server, and library")
                 (description "nghttp2 implements the Hypertext Transfer Protocol, version 2.")
                 (license license:expat)))
